{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}
{% block modal-body-right %}
    <h3>{% trans "Description" %}:</h3>
    <p>{% trans "From here you can modify name and description of a security service." %}</p>
{% endblock %}
